@@ -352,9 +352,15 @@ rstto_navigator_guard_history(RsttoNavigator *navigator, RsttoNavigatorEntry *en
 
         if(entry->src_pixbuf)
         {
-            gdk_pixbuf_unref(entry->src_pixbuf);
+            g_object_unref(entry->src_pixbuf);
             entry->src_pixbuf = NULL;
         }
+
+        if(entry->iter)
+        {
+            g_object_unref(entry->iter);
+            entry->iter = NULL;
+        }
     }
 
     rstto_navigator_add_entry_to_history(navigator, entry);
@@ -939,10 +945,16 @@ rstto_navigator_entry_clear (RsttoNavigatorEntry *nav_entry)
     }
     if(nav_entry->src_pixbuf)
     {
-        gdk_pixbuf_unref(nav_entry->src_pixbuf);
+        g_object_unref(nav_entry->src_pixbuf);
         nav_entry->src_pixbuf = NULL;
     }
 
+    if(nav_entry->iter)
+    {
+        g_object_unref (nav_entry->iter);
+        nav_entry->iter = NULL;
+    }
+
 }
 
 void
@@ -1122,20 +1134,22 @@ rstto_navigator_entry_get_size (RsttoNavigatorEntry *entry)
 
     if (entry->src_pixbuf)
     {
-        width = gdk_pixbuf_get_width(entry->src_pixbuf);
+        width = gdk_pixbuf_get_rowstride(entry->src_pixbuf);
         height = gdk_pixbuf_get_height(entry->src_pixbuf);
 
         n_channels = gdk_pixbuf_get_n_channels(entry->src_pixbuf);
 
-        size += (guint64) width * height * n_channels;
+        //size += (guint64) width * height * n_channels;
+        size += (guint64) width * height;
     }
     if (entry->thumb)
     {
-        width = gdk_pixbuf_get_width(entry->thumb);
+        width = gdk_pixbuf_get_rowstride(entry->thumb);
         height = gdk_pixbuf_get_height(entry->thumb);
 
         n_channels = gdk_pixbuf_get_n_channels(entry->thumb);
-        size += (guint64) width * height * n_channels;
+        //size += (guint64) width * height * n_channels;
+        size += (guint64) width * height;
     }
     
     size += (guint64)sizeof (RsttoNavigatorEntry);
